@@ -50,6 +50,9 @@ module LogStash; class JavaPipeline < AbstractPipeline
 
     @worker_threads = []
 
+    @worker_observer = org.logstash.execution.WorkerObserver.new(process_events_namespace_metric,
+                                                                 pipeline_events_namespace_metric)
+
     @drain_queue =  settings.get_value("queue.drain") || settings.get("queue.type") == MEMORY
 
     @events_filtered = java.util.concurrent.atomic.LongAdder.new
@@ -516,7 +519,10 @@ module LogStash; class JavaPipeline < AbstractPipeline
   end
 
   def stalling_threads_info
-    plugin_threads_info
+    all_threads = plugin_threads_info
+    all_threads << Util.thread_info(@thread) if @thread
+
+    all_threads
       .reject {|t| t["blocked_on"] } # known benign blocking statuses
       .each {|t| t.delete("backtrace") }
       .each {|t| t.delete("blocked_on") }
@@ -578,15 +584,19 @@ module LogStash; class JavaPipeline < AbstractPipeline
   def init_worker_loop
     begin
       org.logstash.execution.WorkerLoop.new(
-        lir_execution,
-        filter_queue_client,
-        @events_filtered,
-        @events_consumed,
-        @flushRequested,
-        @flushing,
-        @shutdownRequested,
-        @drain_queue,
-        @preserve_event_order)
+        filter_queue_client,   # QueueReadClient
+        lir_execution,         # CompiledPipeline
+        @worker_observer,      # WorkerObserver
+        # pipeline reporter counters
+        @events_consumed,      # LongAdder
+        @events_filtered,      # LongAdder
+        # signaling channels
+        @flushRequested,       # AtomicBoolean
+        @flushing,             # AtomicBoolean
+        @shutdownRequested,    # AtomicBoolean
+        # behaviour config pass-through
+        @drain_queue,          # boolean
+        @preserve_event_order) # boolean
     rescue => e
       @logger.error(
         "Worker loop initialization error",
