@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-require "logstash/event"
+
 require "logstash/plugin"
 require "logstash/config/mixin"
 require "concurrent/atomic/atomic_fixnum"
@@ -127,14 +127,18 @@ class LogStash::Outputs::Base < LogStash::Plugin
 
   def execution_context=(context)
     super
-    # There is no easy way to propage an instance variable into the codec, because the codec
-    # are created at the class level
-    # TODO(talevy): Codecs should have their own execution_context, for now they will inherit their
-    #               parent plugin's
+    # Setting the execution context after initialization is deprecated and will be removed in
+    # a future release of Logstash. While this code is no longer executed from Logstash core,
+    # we continue to propagate a set execution context to an output's codec, and rely on super's
+    # deprecation warning.
     @codec.execution_context = context
     context
   end
 
+  def pipeline_shutdown_requested?
+    execution_context.pipeline&.shutdown_requested?
+  end
+
   private
   def output?(event)
     # TODO: noop for now, remove this once we delete this call from all plugins
