@@ -17,21 +17,10 @@
 
 # This class exists to quietly wrap a password string so that, when printed or
 # logged, you don't accidentally print the password itself.
-module LogStash module Util class Password
-  attr_reader :value
 
-  public
-  def initialize(password)
-    @value = password
-  end # def initialize
-
-  public
-  def to_s
-    return "<password>"
-  end # def to_s
-
-  public
-  def inspect
-    return to_s
-  end # def inspect
-end end end # class LogStash::Util::Password
+module LogStash; module Util
+    java_import "co.elastic.logstash.api.Password" # class LogStash::Util::Password
+    java_import "org.logstash.secret.password.PasswordValidator" # class LogStash::Util::PasswordValidator
+    java_import "org.logstash.secret.password.PasswordPolicyType" # class LogStash::Util::PasswordPolicyType
+    java_import "org.logstash.secret.password.PasswordPolicyParam" # class LogStash::Util::PasswordPolicyParam
+end; end
